# Example Python Client
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0) [![npm version](https://badge.fury.io/py/bhalle-example.svg)](https://badge.fury.io/py/bhalle-example) [![CircleCI](https://circleci.com/gh/bhalle/client-python.svg?style=svg)](https://circleci.com/gh/bhalle/client-python)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.4.2
- Package version: 1.4.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import bhalle_example 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import bhalle_example
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import bhalle_example
from bhalle_example.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://petstore.swagger.io/v1
configuration.host = "http://petstore.swagger.io/v1"
# Create an instance of the API class
api_instance = bhalle_example.PetsApi(bhalle_example.ApiClient(configuration))

try:
    # Create a pet
    api_instance.create_pets()
except ApiException as e:
    print("Exception when calling PetsApi->create_pets: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://petstore.swagger.io/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PetsApi* | [**create_pets**](docs/PetsApi.md#create_pets) | **POST** /pets | Create a pet
*PetsApi* | [**list_pets**](docs/PetsApi.md#list_pets) | **GET** /pets | List all pets
*PetsApi* | [**show_pet_by_id**](docs/PetsApi.md#show_pet_by_id) | **GET** /pets/{petId} | Info for a specific pet


## Documentation For Models

 - [Error](docs/Error.md)
 - [Pet](docs/Pet.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




